==> user_hash-2.0.3.tar.gz: user_hash/src/Plugin/Action/GenerateUserHash.php <==
<?php

namespace Drupal\user_hash\Plugin\Action;

use Drupal\Core\Access\AccessResult;
use Drupal\Core\Action\ActionBase;
use Drupal\Core\Session\AccountInterface;
use Drupal\Core\Cache\Cache;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Generate user hashes.
 *
 * @Action(
 *   id = "user_generate_user_hash_action",
 *   label = @Translation("Generate hash for the selected user(s)"),
 *   type = "user"
 * )
 */
class GenerateUserHash extends ActionBase {

  /**
   * @var \Drupal\user_hash\Services|object|null
   */
  protected $userHashService;

  /**
   * @var \Drupal\user\UserData|object|null
   */
  protected $userData;

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition): GenerateUserHash {
    /** @var \Drupal\user_hash\Plugin\Action\GenerateUserHash $instance */
    $instance = parent::create($container, $configuration, $plugin_id, $plugin_definition);
    $instance->userHashService = $container->get('user_hash.services');
    $instance->userData = $container->get('user.data');
    return $instance;
  }

  /**
   * {@inheritdoc}
   */
  public function execute($account = NULL) {
    if ($account !== FALSE) {
      $hash = $this->userHashService->generateHash();
      $this->userData->set('user_hash', $account->id(), 'hash', $hash);
      Cache::invalidateTags(['user:' . $account->id()]);
    }
  }

  /**
   * {@inheritdoc}
   */
  public function access($object, AccountInterface $account = NULL, $return_as_object = FALSE) {
    /** @var \Drupal\user\UserInterface $object */
    $access = $object->status->access('edit', $account, TRUE)
      ->andIf($object->access('update', $account, TRUE))
      ->andIf($object->hasPermission('use user_hash') ? AccessResult::allowed() : AccessResult::forbidden());

    return $return_as_object ? $access : $access->isAllowed();
  }

}

==> user_hash-2.0.5.tar.gz: user_hash/src/Plugin/Action/GenerateUserHash.php <==
<?php

namespace Drupal\user_hash\Plugin\Action;

use Drupal\Core\Access\AccessResult;
use Drupal\Core\Action\ActionBase;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\Core\Session\AccountInterface;
use Drupal\Core\Cache\Cache;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Generate user hashes.
 *
 * @Action(
 *   id = "user_generate_user_hash_action",
 *   label = @Translation("Generate hash for the selected user(s)"),
 *   type = "user"
 * )
 */
class GenerateUserHash extends ActionBase implements ContainerFactoryPluginInterface {

  /**
   * @var \Drupal\user_hash\Services|object|null
   */
  protected $userHashService;

  /**
   * @var \Drupal\user\UserData|object|null
   */
  protected $userData;

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition): GenerateUserHash {
    /** @var \Drupal\user_hash\Plugin\Action\GenerateUserHash $instance */
    $instance = new static($configuration, $plugin_id, $plugin_definition);
    $instance->userHashService = $container->get('user_hash.services');
    $instance->userData = $container->get('user.data');
    return $instance;
  }

  /**
   * {@inheritdoc}
   */
  public function execute($account = NULL) {
    if ($account !== FALSE) {
      $hash = $this->userHashService->generateHash();
      $this->userData->set('user_hash', $account->id(), 'hash', $hash);
      Cache::invalidateTags(['user:' . $account->id()]);
    }
  }

  /**
   * {@inheritdoc}
   */
  public function access($object, AccountInterface $account = NULL, $return_as_object = FALSE) {
    /** @var \Drupal\user\UserInterface $object */
    $access = $object->status->access('edit', $account, TRUE)
      ->andIf($object->access('update', $account, TRUE))
      ->andIf($object->hasPermission('use user_hash') ? AccessResult::allowed() : AccessResult::forbidden());

    return $return_as_object ? $access : $access->isAllowed();
  }

}
